aboutsummaryrefslogtreecommitdiffstats
path: root/test/hook.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/hook.py')
-rw-r--r--test/hook.py20
1 files changed, 12 insertions, 8 deletions
diff --git a/test/hook.py b/test/hook.py
index 90e9bbf5..f3e5f880 100644
--- a/test/hook.py
+++ b/test/hook.py
@@ -100,9 +100,13 @@ class PollHook(Hook):
signaldict = dict(
(k, v) for v, k in reversed(sorted(signal.__dict__.items()))
if v.startswith('SIG') and not v.startswith('SIG_'))
+
+ if self.testcase.vpp.returncode in signaldict:
+ s = signaldict[abs(self.testcase.vpp.returncode)]
+ else:
+ s = "unknown"
msg = "VPP subprocess died unexpectedly with returncode %d [%s]" % (
- self.testcase.vpp.returncode,
- signaldict[abs(self.testcase.vpp.returncode)])
+ self.testcase.vpp.returncode, s)
self.logger.critical(msg)
core_path = self.testcase.tempdir + '/core'
if os.path.isfile(core_path):
@@ -110,27 +114,27 @@ class PollHook(Hook):
self.testcase.vpp_dead = True
raise VppDiedError(msg)
- def after_api(self, api_name, api_args):
+ def before_api(self, api_name, api_args):
"""
Check if VPP died after executing an API
:param api_name: name of the API
:param api_args: tuple containing the API arguments
:raises VppDiedError: exception if VPP is not running anymore
"""
- super(PollHook, self).after_api(api_name, api_args)
+ super(PollHook, self).before_api(api_name, api_args)
self.poll_vpp()
- def after_cli(self, cli):
+ def before_cli(self, cli):
"""
Check if VPP died after executing a CLI
:param cli: CLI string
:raises Exception: exception if VPP is not running anymore
"""
- super(PollHook, self).after_cli(cli)
+ super(PollHook, self).before_cli(cli)
self.poll_vpp()
@@ -110,27 +114,27 @@ class PollHook(Hook):
"""
- Check if VPP died after executing an API
+ Check if VPP died before executing an API
:param api_name: name of the API
:param api_args: tuple containing the API arguments
@@ -110,27 +114,27 @@ class PollHook(Hook):
"""
- Check if VPP died after executing a CLI
+ Check if VPP died before executing a CLI
:param cli: CLI string
:raises Exception: exception if VPP is not running anymore